@@ -3,6 +3,7 @@ import json
 from typing import List
 from functools import reduce
 from datetime import datetime
+from hestia_earth.utils.api import download_hestia
 from hestia_earth.utils.tools import list_average, safe_parse_date
 
 
@@ -117,10 +118,12 @@ def _value_average(node: dict, default=0):
 
 
 def _find_linked_node(node_map: dict, node: dict):
-    return node_map.get(node.get('type'), {}).get(node.get('id'), {})
+    return node_map.get(node.get('type'), {}).get(node.get('id')) or (
+        download_hestia(node.get('@id'), node.get('@type')) if node.get('@id') and node.get('@type') else node
+    )
 
 
-def _is_before_today(date: str): return safe_parse_date(date).date() < datetime.now().date()
+def _is_before_today(date: str): return safe_parse_date(date).date() <= datetime.now().date()
 
 
 def _node_year(node: dict):
