@@ -8,7 +8,7 @@ from .shared import (
     validate_dates, validate_list_dates, validate_date_lt_today, validate_list_min_max,
     validate_list_term_percent, validate_linked_source_privacy, validate_list_dates_length, validate_list_date_lt_today,
     validate_list_model, validate_list_model_config, validate_list_dates_format,
-    validate_list_duplicate_values
+    validate_list_duplicate_values, validate_private_has_source
 )
 from .input import validate_must_include_id, validate_input_country, validate_related_impacts
 from .practice import (
@@ -173,6 +173,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_date_lt_today(cycle, 'startDate'),
         validate_date_lt_today(cycle, 'endDate'),
         validate_linked_source_privacy(cycle, 'defaultSource', node_map),
+        validate_private_has_source(cycle, 'defaultSource'),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
         validate_dataCompleteness(cycle.get('dataCompleteness', {}), site) if 'dataCompleteness' in cycle else True,
         validate_siteDuration(cycle),
