@@ -3,7 +3,7 @@ from hestia_earth.utils.tools import flatten
 from .shared import (
     validate_list_min_max, validate_region_in_country, validate_country, validate_is_region,
     validate_list_term_percent, validate_linked_source_privacy, validate_date_lt_today,
-    validate_list_model
+    validate_list_model, validate_private_has_source
 )
 from .indicator import validate_characterisedIndicator_model
 
@@ -28,6 +28,7 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
         validate_date_lt_today(impact_assessment, 'startDate'),
         validate_date_lt_today(impact_assessment, 'endDate'),
         validate_linked_source_privacy(impact_assessment, 'source', node_map),
+        validate_private_has_source(impact_assessment, 'source'),
         validate_country(impact_assessment) if 'country' in impact_assessment else True,
         validate_is_region(impact_assessment) if 'region' in impact_assessment else True,
         validate_region_in_country(impact_assessment) if 'region' in impact_assessment else True
