@@ -177,8 +177,10 @@ def validate_term_unique(measurements: list):
     return _filter_list_errors(map(validate, enumerate(measurements)))
 
 
-def validate_require_startDate_endDate(measurements: list):
+def validate_require_startDate_endDate(site: dict, list_key: str):
     lookup = download_lookup('measurement.csv')
+    site_start_date = site.get('startDate')
+    site_end_date = site.get('endDate')
 
     def validate(values: tuple):
         index, measurement = values
@@ -186,20 +188,21 @@ def validate_require_startDate_endDate(measurements: list):
         start_date = measurement.get('startDate')
         end_date = measurement.get('endDate')
         required = get_table_value(lookup, 'termid', term_id, column_name('needStartDateEndDate'))
-        return not required or (start_date is not None and end_date is not None) or [
-            {
-                'level': 'error',
-                'dataPath': f".measurements[{index}].startDate",
-                'message': 'is required'
-            },
-            {
-                'level': 'error',
-                'dataPath': f".measurements[{index}].endDate",
-                'message': 'is required'
+        return any([
+            not required,
+            start_date is not None and end_date is not None,
+            site_start_date is not None and start_date == site_start_date,
+            site_end_date is not None and end_date == site_end_date
+        ]) or list(map(lambda k: {
+            'level': 'error',
+            'dataPath': f".{list_key}[{index}]",
+            'message': f"should have required property '{k}'",
+            'params': {
+                'missingProperty': k
             }
-        ]
+        }, ['startDate', 'endDate']))
 
-    return _filter_list_errors(flatten(map(validate, enumerate(measurements))))
+    return _filter_list_errors(flatten(map(validate, enumerate(site.get(list_key, [])))))
 
 
 def validate_with_models(site: dict, list_key: str):
