@@ -1,9 +1,8 @@
-from hestia_earth.validation.gee import is_enabled
 from .shared import (
-    validate_boundary_size, validate_dates, validate_region_in_country, validate_country,
+    validate_dates, validate_region_in_country, validate_country,
     need_validate_coordinates, validate_coordinates,
-    validate_area, need_validate_area, validate_date_lt_today, validate_is_region,
-    validate_area_size, validate_region_size
+    validate_area, need_validate_area, validate_date_lt_today, validate_is_region, validate_area_size,
+    validate_region_size, need_validate_region_size, validate_boundary_size, need_validate_boundary_size
 )
 
 
@@ -41,6 +40,6 @@ def validate_organisation(organisation: dict, node_map: dict = {}):
         validate_coordinates(organisation) if need_validate_coordinates(organisation) else True,
         validate_area(organisation) if need_validate_area(organisation) else True,
         validate_area_size(organisation),
-        validate_region_size(organisation) if is_enabled() else True,
-        validate_boundary_size(organisation) if is_enabled() else True
+        validate_boundary_size(organisation) if need_validate_boundary_size(organisation) else True,
+        validate_region_size(organisation) if need_validate_region_size(organisation) else True
     ]
