@@ -34,8 +34,8 @@ def validate_value_0(products: list):
     def validate(values: tuple):
         index, product = values
         value = list_sum(product.get('value', [-1]), -1)
-        eva = product.get('economicValueShare')
-        revenue = product.get('revenue')
+        eva = product.get('economicValueShare', 0)
+        revenue = product.get('revenue', 0)
         return value != 0 or _filter_list_errors([
             eva == 0 or {
                 'level': 'error',
