@@ -348,6 +348,18 @@ def validate_linked_source_privacy(node: dict, key: str, node_map: dict = {}):
     }
 
 
+def validate_private_has_source(node: dict, key: str):
+    node_private = node.get('dataPrivate')
+    return not node_private or node.get(key) is not None or {
+        'level': 'warning',
+        'dataPath': '.dataPrivate',
+        'message': 'should add a source',
+        'params': {
+            'current': key
+        }
+    }
+
+
 def value_difference(value: float, expected_value: float):
     """
     Get the difference in percentage between a value and the expected value.
