@@ -7,7 +7,8 @@ from .shared import (
     validate_region_in_country, validate_country, validate_is_region, validate_coordinates, need_validate_coordinates,
     validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy,
     validate_list_date_lt_today, validate_date_lt_today, validate_area_size,
-    validate_region_size, need_validate_region_size, validate_boundary_size, need_validate_boundary_size
+    validate_region_size, need_validate_region_size, validate_boundary_size, need_validate_boundary_size,
+    validate_private_has_source
 )
 from .infrastructure import validate_lifespan
 from .measurement import (
@@ -98,6 +99,7 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_date_lt_today(site, 'startDate'),
         validate_date_lt_today(site, 'endDate'),
         validate_linked_source_privacy(site, 'defaultSource', node_map),
+        validate_private_has_source(site, 'defaultSource'),
         validate_siteType(site) if need_validate_coordinates(site) else True,
         validate_country(site) if 'country' in site else True,
         validate_is_region(site) if 'region' in site else True,
@@ -120,7 +122,7 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_term_unique(site.get('measurements')),
         validate_properties_default_value(site, 'measurements'),
         validate_properties_valueType(site, 'measurements'),
-        validate_require_startDate_endDate(site.get('measurements')),
+        validate_require_startDate_endDate(site, 'measurements'),
         validate_with_models(site, 'measurements'),
         validate_value_length(site, 'measurements')
     ] if 'measurements' in site else []) + flatten([
