@@ -203,27 +203,30 @@ def test_validate_term_unique_invalid():
 
 def test_validate_require_startDate_endDate_valid():
     # no measurements should be valid
-    assert validate_require_startDate_endDate([]) is True
+    assert validate_require_startDate_endDate({'measurements': []}, 'measurements') is True
 
     with open(f"{fixtures_path}/measurement/startDate-endDate-required/valid.json") as f:
         data = json.load(f)
-    assert validate_require_startDate_endDate(data.get('nodes')) is True
+    assert validate_require_startDate_endDate(data, 'measurements') is True
 
 
 def test_validate_require_startDate_endDate_invalid():
-    # no measurements should be valid
-    assert validate_require_startDate_endDate([]) is True
-
     with open(f"{fixtures_path}/measurement/startDate-endDate-required/invalid.json") as f:
         data = json.load(f)
-    assert validate_require_startDate_endDate(data.get('nodes')) == [{
+    assert validate_require_startDate_endDate(data, 'measurements') == [{
         'level': 'error',
-        'dataPath': '.measurements[0].startDate',
-        'message': 'is required'
+        'dataPath': '.measurements[0]',
+        'message': "should have required property 'startDate'",
+        'params': {
+            'missingProperty': 'startDate'
+        }
     }, {
         'level': 'error',
-        'dataPath': '.measurements[0].endDate',
-        'message': 'is required'
+        'dataPath': '.measurements[0]',
+        'message': "should have required property 'endDate'",
+        'params': {
+            'missingProperty': 'endDate'
+        }
     }]
 
 
