@@ -10,7 +10,8 @@ from hestia_earth.validation.validators.shared import (
     validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
     value_difference, is_value_different, validate_list_model, validate_list_model_config,
     validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size,
-    validate_boundary_size, need_validate_boundary_size, validate_region_size, need_validate_region_size
+    validate_boundary_size, need_validate_boundary_size, validate_region_size, need_validate_region_size,
+    validate_private_has_source
 )
 from hestia_earth.validation.validators.cycle import PRODUCTS_MODEL_CONFIG
 
@@ -333,6 +334,34 @@ def test_validate_empty_fields_warning():
     }]
 
 
+def test_validate_private_has_source_valid():
+    # valid if public
+    node = {'dataPrivate': False}
+    assert validate_private_has_source(node, 'source') is True
+
+    # valid if private and with Source
+    node = {
+        'source': {
+            'type': 'Source',
+            'id': '1'
+        },
+        'dataPrivate': True
+    }
+    assert validate_private_has_source(node, 'source') is True
+
+
+def test_validate_private_has_source_warning():
+    node = {'dataPrivate': True}
+    assert validate_private_has_source(node, 'source') == {
+        'level': 'warning',
+        'dataPath': '.dataPrivate',
+        'message': 'should add a source',
+        'params': {
+            'current': 'source'
+        }
+    }
+
+
 def test_validate_linked_source_privacy_valid():
     node = {
         'source': {
